"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const request_interception_1 = require("./request-interception");
const spec = [
    {
        framework: 'dom',
        url: 'http://localhost:4444/',
        taggingMethod: 'event',
        selector: 'html > body > div#top > main:nth-child(3) > section#forms > form:nth-child(4) > fieldset#forms__textareas > p:nth-child(2) > textarea#textarea',
        handler: 'focus',
        event: 'Focused Textarea'
    },
    {
        framework: 'dom',
        url: 'http://localhost:4444/',
        taggingMethod: 'event',
        selector: 'html > body > div#top > main:nth-child(3) > section#embedded > article#embedded__images > div:nth-child(2) > p:nth-child(2) > img:nth-child(1)',
        handler: 'click',
        event: 'Click Picture'
    },
    {
        framework: 'dom',
        url: 'http://localhost:4444',
        taggingMethod: 'form',
        formAction: 'identify',
        handler: 'submit',
        selector: 'html > body > div#top > main:nth-child(3) > section#forms > div.log-form > form:nth-child(2)',
        bindings: [
            {
                selector: 'input[name="name"]',
                field: 'name',
                userIdentifier: false
            },
            {
                selector: 'input[name="email"]',
                field: 'email',
                userIdentifier: true
            }
        ]
    },
    {
        framework: 'dom',
        url: 'http://localhost:4444',
        taggingMethod: 'form',
        formAction: 'track',
        handler: 'submit',
        event: 'Submitted Form with Properties',
        selector: 'html > body > div#top > main:nth-child(3) > section#forms > div.favorite-form > form:nth-child(2)',
        bindings: [
            {
                selector: 'input[name="food"]',
                field: 'food'
            },
            {
                selector: 'input[name="place"]',
                field: 'place'
            }
        ]
    },
    {
        framework: 'dom',
        url: 'http://localhost:4444/',
        taggingMethod: 'event',
        selector: 'html > body > div#top > div.panel-footer > div.fusion-button-wrapper > a.fusion-button',
        handler: 'click',
        event: 'Clicked Link With Embedded Markup'
    }
];
const responseMap = {
    's3-us-west-2.amazonaws.com': spec,
    'api.segment.io': { success: true }
};
describe('Tracktor', () => {
    beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
        request_interception_1.interceptRequests(page, responseMap);
        yield page.goto('http://localhost:4444');
        yield page.waitForFunction('Tracktor.instance.isInitialized()');
    }));
    it.skip('should emit correct track event on focus of <textarea> elements', () => __awaiter(void 0, void 0, void 0, function* () {
        const textareaFocusTag = spec[0];
        yield expect(page).toClick(textareaFocusTag.selector);
        const ajsTrackCall = yield page
            .waitForRequest(request => request.url().startsWith('https://api.segment.io'))
            .then(e => e.postData())
            .then(JSON.parse);
        expect(ajsTrackCall.event).toEqual(textareaFocusTag.event);
    }));
    it('should emit correct track event on click of an image', () => __awaiter(void 0, void 0, void 0, function* () {
        const imageClickedTag = spec[1];
        yield expect(page).toClick(imageClickedTag.selector);
        const ajsTrackCall = yield page
            .waitForRequest(request => request.url().startsWith('https://api.segment.io/v1/t'))
            .then(e => e.postData())
            .then(JSON.parse);
        expect(ajsTrackCall.event).toEqual(imageClickedTag.event);
    }));
    it('should emit an identify call when a tagged form (of formAction=identify) is submitted', () => __awaiter(void 0, void 0, void 0, function* () {
        const formSubmittedTag = spec[2];
        const name = 'John Doe';
        const email = 'jdoe@segment.com';
        yield expect(page).toFillForm(formSubmittedTag.selector, { name, email });
        yield expect(page).toClick(formSubmittedTag.selector + ' > button');
        const ajsIdentifyCall = yield page
            .waitForRequest(request => request.url().startsWith('https://api.segment.io/v1/i'))
            .then(e => e.postData())
            .then(JSON.parse);
        expect(ajsIdentifyCall.type).toEqual('identify');
        expect(ajsIdentifyCall.traits).toEqual({ name });
        expect(ajsIdentifyCall.userId).toEqual(email);
        expect(ajsIdentifyCall.context.visual_tagger).toBeTruthy();
    }));
    it('should emit an track call when a tagged form (of formAction=track) is submitted', () => __awaiter(void 0, void 0, void 0, function* () {
        const formSubmittedTag = spec[3];
        const food = 'Pizza';
        const place = 'Vancouver';
        yield page.goto('http://localhost:4444');
        yield expect(page).toFillForm(formSubmittedTag.selector, { food, place });
        yield expect(page).toClick(formSubmittedTag.selector + ' > button');
        const ajsTrackCall = yield page
            .waitForRequest(request => request.url().startsWith('https://api.segment.io/v1/t'))
            .then(e => e.postData())
            .then(JSON.parse);
        expect(ajsTrackCall.type).toEqual('track');
        expect(ajsTrackCall.properties).toEqual({ place, food });
        expect(ajsTrackCall.context.visual_tagger).toBeTruthy();
    }));
    it('should emit correct track event on click of an element with embedded markup', () => __awaiter(void 0, void 0, void 0, function* () {
        const embeddedMarkupClickTag = spec[4];
        yield page.goto('http://localhost:4444');
        yield expect(page).toClick(embeddedMarkupClickTag.selector + ' > span.fusion-button-text');
        const ajsTrackCall = yield page
            .waitForRequest(request => request.url().startsWith('https://api.segment.io'))
            .then(e => e.postData())
            .then(JSON.parse);
        expect(ajsTrackCall.event).toEqual(embeddedMarkupClickTag.event);
    }));
});
//# sourceMappingURL=dom-injector.test.js.map