"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const request_interception_1 = require("./request-interception");
const spec = [
    {
        framework: 'dom',
        url: 'http://localhost:4444/',
        taggingMethod: 'event',
        selector: 'html > body > div#top > main:nth-child(3) > section#embedded > article#embedded__images > div:nth-child(2) > p:nth-child(2) > img:nth-child(1)',
        handler: 'click',
        event: 'Click Picture'
    }
];
const newSpec = [
    {
        framework: 'dom',
        url: 'http://localhost:4444/',
        taggingMethod: 'event',
        selector: 'html > body > div#top > main:nth-child(3) > section#embedded > article#embedded__images > div:nth-child(2) > p:nth-child(2) > img:nth-child(1)',
        handler: 'click',
        event: 'Click New Picture'
    }
];
const responseMap = {
    's3-us-west-2.amazonaws.com': spec,
    'api.segment.io': { success: true }
};
describe('Tracktor', () => {
    beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
        request_interception_1.interceptRequests(page, responseMap);
        yield page.goto('http://localhost:4444');
        yield page.waitForFunction('Tracktor.instance.isInitialized()');
    }));
    it('should fire an event with the new spec when restart is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const imageClickedTag = spec[0];
        const imageClickedNewTag = newSpec[0];
        page.waitForFunction(`Tracktor.instance.restart(${JSON.stringify(newSpec)})`);
        yield expect(page).toClick(imageClickedTag.selector);
        const ajsTrackCall = yield page
            .waitForRequest(request => request.url().startsWith('https://api.segment.io/v1/t'))
            .then(e => e.postData())
            .then(JSON.parse);
        expect(ajsTrackCall.event).toEqual(imageClickedNewTag.event);
    }));
});
//# sourceMappingURL=overwrite-spec.test.js.map